@@ -10,13 +10,13 @@ use namespace::autoclean;
 
 no warnings 'experimental';
 
-our $VERSION='1.213';
+our $VERSION='1.214';
 
 =head1 NAME
 
 Vote::Count::Redact
 
-=head1 VERSION 1.213
+=head1 VERSION 1.214
 
 Methods for Redacting Ballots.
 
@@ -36,7 +36,7 @@ use Exporter::Easy ( OK => [qw( RedactSingle RedactPair RedactBullet )], );
 
 Takes a list (array) of choices to be converted to bullet votes. Returns a modified BallotSet where all votes that had a first choice vote for a member of the list are votes for only that choice.
 
-  my $newBallotSet = RedactBullet( $VoteCountObject->BallotSet(), 'A', 'B', 'F');
+  my $newBallotSet = RedactBullet( $Election->BallotSet(), 'A', 'B', 'F');
 
 =cut
 
@@ -85,14 +85,10 @@ REDACTSINGLELOOP:
 
 =head2 RedactPair
 
-For a Ballot Set and two choices, on each ballot where both appear it removes the later one and all subsequent choices, returning a completely independent new BallotSet. It is necessary to remove later choices, because otherwise the ballot would be voting against the target later choice, not merely not voting for.
+For a Ballot Set and two choices, on each ballot where both appear it removes the later one and all subsequent choices, returning a completely independent new BallotSet. If the later choices were left intact, they would become votes against the redacted choices in those pairings.
 
   my $newBallotSet = RedactPair( $VoteCountObject->BallotSet(), 'A', 'B');
 
-=head3 Todo for RedactPair
-
-Add options to only apply to first choice votes, either making them bullets or only redacting the opposing choice from first choice votes.
-
 =cut
 
 # RedactPair only alters votes involving the two choices
